@@ -251,8 +251,10 @@ class Cube(object):
         categories.
         """
         return (
-            self._measures.valid_counts.raw_cube_array
-            if self._measures.valid_counts is not None
+            self._measures.weighted_valid_counts.raw_cube_array
+            if self._measures.weighted_valid_counts is not None
+            else self._measures.unweighted_valid_counts.raw_cube_array
+            if self._measures.unweighted_valid_counts is not None
             else self._measures.weighted_counts.raw_cube_array
             if self.has_weighted_counts
             else self._measures.unweighted_counts.raw_cube_array
@@ -441,22 +443,32 @@ class Cube(object):
         with the valid counts measure.
         """
         unweighted_counts = (
-            self._measures.valid_counts
-            if self._measures.valid_counts is not None
+            self._measures.unweighted_valid_counts
+            if self._measures.unweighted_valid_counts is not None
             else self._measures.unweighted_counts
         )
         return unweighted_counts.raw_cube_array[self._valid_idxs]
 
+    @lazyproperty
+    def unweighted_valid_counts(self):
+        """Optional float64 ndarray of unweighted_valid_counts if the measure exists."""
+        if self._measures.unweighted_valid_counts is None:
+            return None
+        return self._measures.unweighted_valid_counts.raw_cube_array[
+            self._valid_idxs
+        ].astype(np.float64)
+
     @lazyproperty
     def valid_counts_summary(self):
         """Optional ndarray of summary valid counts"""
-        if not self._measures.valid_counts:
+        if not self._measures.unweighted_valid_counts:
             return None
         # --- In case of ndim >= 2 the sum should be done on the second axes to get
         # --- the correct sequence of valid count (e.g. CA_SUBVAR).
         axis = 1 if len(self._all_dimensions) >= 2 else 0
         return np.sum(
-            self._measures.valid_counts.raw_cube_array[self._valid_idxs], axis=axis
+            self._measures.unweighted_valid_counts.raw_cube_array[self._valid_idxs],
+            axis=axis,
         )
 
     @lazyproperty
@@ -480,8 +492,8 @@ class Cube(object):
         are replaced with the valid counts measure.
         """
         weighted_counts = (
-            self._measures.valid_counts
-            if self._measures.valid_counts is not None
+            self._measures.weighted_valid_counts
+            if self._measures.weighted_valid_counts is not None
             else self._measures.weighted_counts
         )
         return (
@@ -490,6 +502,15 @@ class Cube(object):
             else None
         )
 
+    @lazyproperty
+    def weighted_valid_counts(self):
+        """Optional float64 ndarray of weighted_valid_counts if the measure exists."""
+        if self._measures.weighted_valid_counts is None:
+            return None
+        return self._measures.weighted_valid_counts.raw_cube_array[
+            self._valid_idxs
+        ].astype(np.float64)
+
     @lazyproperty
     def _all_dimensions(self):
         """The AllDimensions object for this cube.
@@ -679,8 +700,8 @@ class _Measures(object):
     @lazyproperty
     def missing_count(self):
         """numeric representing count of missing rows in cube response."""
-        if self.valid_counts is not None:
-            return self.valid_counts.missing_count
+        if self.unweighted_valid_counts is not None:
+            return self.unweighted_valid_counts.missing_count
         # The check on the means measure is needed for retro-compatibility with the old
         # fixtures that don't have valid_counts.
         if self.means is not None:
@@ -714,18 +735,21 @@ class _Measures(object):
         """
 
         # Try and get the new-style complete-cases filtered counts
-        filter_stats = (
-            self._cube_dict["result"]
-            .get("filter_stats", {})
-            .get("filtered_complete", {})
-            .get("weighted")
+        filter_stats = self._cube_dict["result"].get("filter_stats", {})
+        weighted_filtered_complete = filter_stats.get("filtered_complete", {}).get(
+            "weighted"
         )
-        if filter_stats:
-            # If new format is present in response json, use that for pop fraction
-            numerator = filter_stats["selected"]
-            denominator = numerator + filter_stats["other"]
+        if weighted_filtered_complete:
+            # ---If the filter consists of a single categorical date variable, we need
+            # ---to treat the population fraction as 1, as it's constant accross dates
+            if filter_stats.get("is_cat_date"):
+                return 1
+
+            # ---If new format is present in response json, use that for pop fraction
+            numerator = weighted_filtered_complete["selected"]
+            denominator = numerator + weighted_filtered_complete["other"]
         else:
-            # If new format is not available, default to old-style calculation
+            # ---If new format is not available, default to old-style calculation
             numerator = self._cube_dict["result"].get("filtered", {}).get("weighted_n")
             denominator = (
                 self._cube_dict["result"].get("unfiltered", {}).get("weighted_n")
@@ -770,12 +794,12 @@ class _Measures(object):
         )
 
     @lazyproperty
-    def valid_counts(self):
-        """_ValidCountsMeasure object for this cube.
+    def unweighted_valid_counts(self):
+        """_UnweightedValidCountsMeasure object for this cube.
 
-        Can be None when cube doesn't have valid counts.
+        Can be None when cube doesn't have unweighted valid counts.
         """
-        valid_counts = _ValidCountsMeasure(
+        valid_counts = _UnweightedValidCountsMeasure(
             self._cube_dict, self._all_dimensions, self._cube_idx_arg
         )
         return valid_counts if valid_counts.raw_cube_array is not None else None
@@ -802,6 +826,17 @@ class _Measures(object):
         )
         return weighted_counts if weighted_counts.raw_cube_array is not None else None
 
+    @lazyproperty
+    def weighted_valid_counts(self):
+        """_WeightedValidCountsMeasure object for this cube.
+
+        Can be None when cube doesn't have weighted valid counts.
+        """
+        valid_counts = _WeightedValidCountsMeasure(
+            self._cube_dict, self._all_dimensions, self._cube_idx_arg
+        )
+        return valid_counts if valid_counts.raw_cube_array is not None else None
+
 
 class _BaseMeasure(object):
     """Base class for measure objects."""
@@ -999,8 +1034,8 @@ class _UnweightedCountMeasure(_BaseMeasure):
         return np.array(self._cube_dict["result"]["counts"], dtype=np.float64)
 
 
-class _ValidCountsMeasure(_BaseMeasure):
-    """Valid counts for cube."""
+class _UnweightedValidCountsMeasure(_BaseMeasure):
+    """Unweighted Valid counts for cube."""
 
     @lazyproperty
     def missing_count(self):
@@ -1011,7 +1046,7 @@ class _ValidCountsMeasure(_BaseMeasure):
 
     @lazyproperty
     def _flat_values(self):
-        """Optional 1D np.ndarray of np.float64 valid counts."""
+        """Optional 1D np.ndarray of np.float64 unweighted valid counts."""
         valid_counts = (
             self._cube_dict["result"]["measures"]
             .get("valid_count_unweighted", {})
@@ -1043,3 +1078,17 @@ class _WeightedCountMeasure(_BaseMeasure):
             return None
 
         return np.array(weighted_counts, dtype=np.float64)
+
+
+class _WeightedValidCountsMeasure(_BaseMeasure):
+    """Weighted Valid counts for cube."""
+
+    @lazyproperty
+    def _flat_values(self):
+        """Optional 1D np.ndarray of np.float64 weighted valid counts."""
+        valid_counts = (
+            self._cube_dict["result"]["measures"]
+            .get("valid_count_weighted", {})
+            .get("data", [])
+        )
+        return np.array(valid_counts, dtype=np.float64) if valid_counts else None
