@@ -219,7 +219,12 @@ class _CatXMrOverlaps(_BaseCubeOverlaps):
     """Overlaps cube-measure for a NOT_MR_X_MR slice."""
 
     @lazyproperty
-    def overlaps(self):
+    def tile_repetitions(self):
+        """tuple of number of repetitions of selected base matrix."""
+        return (self._overlaps.shape[0], 1, 1)
+
+    @lazyproperty
+    def selected_bases(self):
         """3D np.float64 ndarray of selected overlaps between MR subvariables, per cat.
 
         For a CAT x MR matrix, the overlaps are calculated for each category, and then
@@ -230,12 +235,16 @@ class _CatXMrOverlaps(_BaseCubeOverlaps):
         of the previous MR_SUBVAR dimension.
 
         From this shape, we only need the "Selected" part of the MR_SEL dimension, so
-        we need to select the 0th element along the 2nd axis [:, :, 0].
+        we need to select the 0th element along the 2nd axis [:, :, 0]. But we also need
+        to add all of the categories together, since that's what's used for the base
+        value in all of the significance calculations. We then tile these bases, since
+        they're the same for each row (all the categories added together). The tiling is
+        done so that the API of this class can be uniform for all users.
         """
-        return self._overlaps[:, :, 0]
+        return np.tile(np.sum(self._overlaps[:, :, 0], axis=0), self.tile_repetitions)
 
     @lazyproperty
-    def valid_overlaps(self):
+    def valid_bases(self):
         """3D np.float64 ndarray of valid overlaps between MR subvariables, per cat.
 
         For a CAT x MR matrix, the overlaps are calculated for each category, and then
@@ -249,15 +258,16 @@ class _CatXMrOverlaps(_BaseCubeOverlaps):
         dimension (i.e. all except missing), so we need to add the 0th and the 1st
         element along the 2nd axis sum([:, :, 0:2]).
         """
-        return np.sum(self._valid_overlaps[:, :, 0:2], axis=2)
+        valids = np.sum(self._valid_overlaps[:, :, 0:2], axis=2)
+        return np.tile(np.sum(valids, axis=0), self.tile_repetitions)
 
 
 class _MrXMrOverlaps(_BaseCubeOverlaps):
     """Overlaps cube-measure for a MR_X_MR slice."""
 
     @lazyproperty
-    def overlaps(self):
-        """3D np.float64 ndarray of selected overlaps between MR subvariables, per cat.
+    def selected_bases(self):
+        """3D np.float64 ndarray of selected overlaps bases between MR subvariables.
 
         For a MR x MR slice, the overlaps are calculated for each MR subvar row, and
         then for each subvariables pair for that row (which will produce a square
@@ -266,13 +276,17 @@ class _MrXMrOverlaps(_BaseCubeOverlaps):
         being the result of the `cube_overlap` measure, and representing the "pairing"
         with each subvar of the last MR_SUBVAR dimension.
 
-        From this shape, we only need the "Selected" part of both MR_SEL dimensions, so
-        we need to select the 0th element along the 1st and 3rd axes [:, 0, :, 0].
+        From this shape, we only need the "Selected" part of the last MR_SEL dimension,
+        but we need both "Selected" and "Other" from the first MR_SEL dimension. We
+        therefore need to select the 0th element along the 3rd axis, but we need to sum
+        the 0th and 1st elements along the 1st axis (first MR_SEL dimension). The sum
+        of the selected and other counts of the first MR_SEL is what's always used to
+        represent bases of such crosstabs (we cannot simply ignore the other counts).
         """
-        return self._overlaps[:, 0, :, 0]
+        return np.sum(self._overlaps[:, 0:2, :, 0], axis=1)
 
     @lazyproperty
-    def valid_overlaps(self):
+    def valid_bases(self):
         """3D np.float64 ndarray of valid overlaps between MR subvariables, per row.
 
         For a MR x MR slice, the overlaps are calculated for each row, and then
@@ -459,17 +473,24 @@ class _MrXMrCubeSums(_BaseCubeSums):
 class _BaseUnweightedCubeCounts(_BaseCubeMeasure):
     """Base class for unweighted-count cube-measure variants."""
 
-    def __init__(self, dimensions, unweighted_counts):
+    def __init__(self, dimensions, unweighted_counts, diff_nans):
         super(_BaseUnweightedCubeCounts, self).__init__(dimensions)
         self._unweighted_counts = unweighted_counts
+        self._diff_nans = diff_nans
 
     @classmethod
     def factory(cls, cube, dimensions, slice_idx):
         """Return _BaseUnweightedCubeCounts subclass instance appropriate to `cube`."""
         dimension_types = cube.dimension_types[-2:]
-
+        valid_counts = cube.unweighted_valid_counts
+        counts = valid_counts if valid_counts is not None else cube.unweighted_counts
+        diff_nans = True if valid_counts is not None else False
         UnweightedCubeCountsCls = (
-            _MrXMrUnweightedCubeCounts
+            _NumArrayXMrUnweightedCubeCounts
+            if dimension_types == (DT.NUM_ARRAY, DT.MR)
+            else _NumArrayXCatUnweightedCubeCounts
+            if dimension_types[0] == DT.NUM_ARRAY
+            else _MrXMrUnweightedCubeCounts
             if dimension_types == (DT.MR, DT.MR)
             else _MrXCatUnweightedCubeCounts
             if dimension_types[0] == DT.MR
@@ -479,7 +500,7 @@ class _BaseUnweightedCubeCounts(_BaseCubeMeasure):
         )
 
         return UnweightedCubeCountsCls(
-            dimensions, cube.unweighted_counts[cls._slice_idx_expr(cube, slice_idx)]
+            dimensions, counts[cls._slice_idx_expr(cube, slice_idx)], diff_nans
         )
 
     @lazyproperty
@@ -501,6 +522,11 @@ class _BaseUnweightedCubeCounts(_BaseCubeMeasure):
             "%s must implement `.columns_pruning_base`" % type(self).__name__
         )
 
+    @lazyproperty
+    def diff_nans(self):
+        """Boolean, indicated if subtotal differences (rows and cols) has to be NaN."""
+        return self._diff_nans
+
     @lazyproperty
     def row_bases(self):
         """2D np.float64 ndarray of unweighted row-proportion denominator per cell."""
@@ -828,21 +854,56 @@ class _MrXMrUnweightedCubeCounts(_BaseUnweightedCubeCounts):
         return self._unweighted_counts[:, 0, :, 0]
 
 
+class _NumArrayXCatUnweightedCubeCounts(_CatXCatUnweightedCubeCounts):
+    """Unweighted-counts cube-measure for a slice with no NUM ARRAY row dimension."""
+
+    @lazyproperty
+    def column_bases(self):
+        """2D np.float64 ndarray of column-wise unweighted-N for each matrix cell."""
+        return np.broadcast_to(
+            np.sum(self.columns_base, axis=0), self.unweighted_counts.shape
+        )
+
+    @lazyproperty
+    def columns_base(self):
+        """2D ndarray of np.float64 unweighted-N for each matrix column."""
+        return self._unweighted_counts
+
+
+class _NumArrayXMrUnweightedCubeCounts(_CatXMrUnweightedCubeCounts):
+    """Unweighted-counts cube-measure for a slice with NUM_ARRAY x MR dimensions."""
+
+    @lazyproperty
+    def column_bases(self):
+        """2D np.float64 ndarray of column-wise unweighted-N for each matrix cell."""
+        return np.broadcast_to(
+            np.sum(self.columns_base, axis=0), self.unweighted_counts.shape
+        )
+
+    @lazyproperty
+    def columns_base(self):
+        """2D ndarray of np.float64 unweighted-N for each matrix column."""
+        return self._unweighted_counts[:, :, 0]
+
+
 # === WEIGHTED COUNTS ===
 
 
 class _BaseWeightedCubeCounts(_BaseCubeMeasure):
     """Base class for weighted-count cube-measure variants."""
 
-    def __init__(self, dimensions, weighted_counts):
+    def __init__(self, dimensions, weighted_counts, diff_nans):
         super(_BaseWeightedCubeCounts, self).__init__(dimensions)
         self._weighted_counts = weighted_counts
+        self._diff_nans = diff_nans
 
     @classmethod
     def factory(cls, cube, dimensions, slice_idx):
         """Return _BaseWeightedCounts subclass instance appropriate to `cube`."""
         dimension_types = cube.dimension_types[-2:]
-
+        valid_counts = cube.weighted_valid_counts
+        counts = valid_counts if valid_counts is not None else cube.counts
+        diff_nans = True if valid_counts is not None else False
         WeightedCubeCountsCls = (
             _MrXMrWeightedCubeCounts
             if dimension_types == (DT.MR, DT.MR)
@@ -853,7 +914,7 @@ class _BaseWeightedCubeCounts(_BaseCubeMeasure):
             else _CatXCatWeightedCubeCounts
         )
         return WeightedCubeCountsCls(
-            dimensions, cube.counts[cls._slice_idx_expr(cube, slice_idx)]
+            dimensions, counts[cls._slice_idx_expr(cube, slice_idx)], diff_nans
         )
 
     @lazyproperty
@@ -868,6 +929,11 @@ class _BaseWeightedCubeCounts(_BaseCubeMeasure):
             "%s must implement `.columns_margin`" % type(self).__name__
         )
 
+    @lazyproperty
+    def diff_nans(self):
+        """Boolean, indicated if subtotal differences (rows and cols) has to be NaN."""
+        return self._diff_nans
+
     @lazyproperty
     def row_bases(self):
         """2D np.float64 ndarray of (weighted) row-proportion denominator per cell."""
@@ -911,6 +977,28 @@ class _BaseWeightedCubeCounts(_BaseCubeMeasure):
             "`%s` must implement `.weighted_counts`" % type(self).__name__
         )
 
+    @lazyproperty
+    def zscores(self):
+        """2D np.float64 ndarray of zscores for each valid matrix cell."""
+        raise NotImplementedError(  # pragma: no cover
+            "`%s` must implement `.zscores`" % type(self).__name__
+        )
+
+    def _array_type_std_res(self, counts, total, rowsum, colsum):
+        """Return 2D np.float64 ndarray of std-res value for each cell of MR matrix.
+
+        This is a utility method used by a matrix with one or more MR dimensions. The
+        caller forms the input arrays based on which of its dimensions are MR.
+        """
+        # --- if the matrix is "defective", in the sense that it doesn't have at least
+        # --- two rows and two columns that are "full" of data, don't calculate zscores.
+        if not np.all(counts.shape) or np.linalg.matrix_rank(counts) < 2:
+            return np.full(counts.shape, np.nan)
+
+        expected_counts = rowsum * colsum / total
+        variance = rowsum * colsum * (total - rowsum) * (total - colsum) / total ** 3
+        return (counts - expected_counts) / np.sqrt(variance)
+
 
 class _CatXCatWeightedCubeCounts(_BaseWeightedCubeCounts):
     """Weighted-counts cube-measure for a slice with no MR dimensions."""
@@ -953,6 +1041,36 @@ class _CatXCatWeightedCubeCounts(_BaseWeightedCubeCounts):
         """
         return self._weighted_counts
 
+    @lazyproperty
+    def zscores(self):
+        """2D ndarray of np.float64 std-res value for each cell of matrix.
+
+        A z-score is also known as a *standard score* and is the number of standard
+        deviations above (positive) or below (negative) the population mean a cell's
+        value is.
+        """
+        counts = self.weighted_counts
+
+        # --- If the matrix is "defective", in the sense that it doesn't have at least
+        # --- two rows and two columns that are "full" of data, don't calculate zscores.
+        if not np.all(counts.shape) or np.linalg.matrix_rank(counts) < 2:
+            return np.full(counts.shape, np.nan)
+
+        residuals = counts - expected_freq(counts)
+
+        # --- variance of the residuals ---
+        rows_margin = self.rows_margin
+        columns_margin = self.columns_margin
+        table_margin = self.table_margin
+        variance_of_residuals = (
+            np.outer(rows_margin, columns_margin)
+            * np.outer(table_margin - rows_margin, table_margin - columns_margin)
+            / table_margin ** 3
+        )
+
+        with np.errstate(divide="ignore", invalid="ignore"):
+            return residuals / np.sqrt(variance_of_residuals)
+
 
 class _CatXMrWeightedCubeCounts(_BaseWeightedCubeCounts):
     """Weighted-counts cube-measure for a NOT_MR_X_MR slice.
@@ -1012,6 +1130,16 @@ class _CatXMrWeightedCubeCounts(_BaseWeightedCubeCounts):
         """
         return self._weighted_counts[:, :, 0]
 
+    @lazyproperty
+    def zscores(self):
+        """2D np.float64 ndarray of z-score for each matrix cell."""
+        return self._array_type_std_res(
+            self.weighted_counts,
+            self.table_margin,
+            np.sum(self._weighted_counts, axis=2),
+            np.sum(self.weighted_counts, axis=0),
+        )
+
 
 class _MrXCatWeightedCubeCounts(_BaseWeightedCubeCounts):
     """Weighted-counts cube-measure for an MR_X_NOT_MR slice.
@@ -1065,6 +1193,16 @@ class _MrXCatWeightedCubeCounts(_BaseWeightedCubeCounts):
         """
         return self._weighted_counts[:, 0, :]
 
+    @lazyproperty
+    def zscores(self):
+        """2D np.float64 ndarray of z-score for each matrix cell."""
+        return self._array_type_std_res(
+            self.weighted_counts,
+            self.table_margin[:, np.newaxis],
+            np.sum(self.weighted_counts, axis=1)[:, None],
+            np.sum(self._weighted_counts, axis=1),
+        )
+
 
 class _MrXMrWeightedCubeCounts(_BaseWeightedCubeCounts):
     """Weighted-counts cube-measure for an MR_X_MR slice.
@@ -1132,6 +1270,21 @@ class _MrXMrWeightedCubeCounts(_BaseWeightedCubeCounts):
         """
         return self._weighted_counts[:, 0, :, 0]
 
+    @lazyproperty
+    def zscores(self):
+        """2D ndarray of np.float64 std-res value for each cell of matrix.
+
+        A z-score is also known as a *standard score* and is the number of standard
+        deviations above (positive) or below (negative) the population mean each cell's
+        value is.
+        """
+        return self._array_type_std_res(
+            self.weighted_counts,
+            self.table_margin,
+            np.sum(self._weighted_counts, axis=3)[:, 0, :],
+            np.sum(self._weighted_counts, axis=1)[:, :, 0],
+        )
+
 
 # === LEGACY MATRIX OBJECTS ===
 
@@ -1152,11 +1305,7 @@ class BaseCubeResultMatrix(object):
         """Return a base-matrix object of appropriate type for `cube`."""
         dimension_types = cube.dimension_types[-2:]
         MatrixCls = (
-            _NumArrayXMrMatrix
-            if dimension_types == (DT.NUM_ARRAY, DT.MR)
-            else _NumArrayXCatMatrix
-            if dimension_types[0] == DT.NUM_ARRAY
-            else _MrXMrMatrix
+            _MrXMrMatrix
             if dimension_types == (DT.MR, DT.MR)
             else _MrXCatMatrix
             if dimension_types[0] == DT.MR
@@ -1189,13 +1338,6 @@ class BaseCubeResultMatrix(object):
         """
         return self.weighted_counts / self.columns_margin
 
-    @lazyproperty
-    def columns_base(self):
-        """1D/2D np.float64 ndarray of unweighted-N for each matrix column/cell."""
-        raise NotImplementedError(
-            "`%s` must implement `.columns_base`" % type(self).__name__
-        )  # pragma: no cover
-
     @lazyproperty
     def columns_dimension(self):
         """The `Dimension` object representing column elements of this matrix."""
@@ -1292,33 +1434,6 @@ class BaseCubeResultMatrix(object):
             "`%s` must implement `.weighted_counts`" % type(self).__name__
         )  # pragma: no cover
 
-    @lazyproperty
-    def zscores(self):
-        """2D ndarray of np.float64 std-res value for each cell of matrix.
-
-        A z-score is also known as a *standard score* and is the number of standard
-        deviations above (positive) or below (negative) the population mean a cell's
-        value is.
-        """
-        raise NotImplementedError(
-            "`%s` must implement `.zscores`" % type(self).__name__
-        )  # pragma: no cover
-
-    def _array_type_std_res(self, counts, total, rowsum, colsum):
-        """Return 2D np.float64 ndarray of std-res value for each cell of MR matrix.
-
-        This is a utility method used by a matrix with one or more MR dimensions. The
-        caller forms the input arrays based on which of its dimensions are MR.
-        """
-        # --- if the matrix is "defective", in the sense that it doesn't have at least
-        # --- two rows and two columns that are "full" of data, don't calculate zscores.
-        if not np.all(counts.shape) or np.linalg.matrix_rank(counts) < 2:
-            return np.zeros(counts.shape)
-
-        expected_counts = rowsum * colsum / total
-        variance = rowsum * colsum * (total - rowsum) * (total - colsum) / total ** 3
-        return (counts - expected_counts) / np.sqrt(variance)
-
     @staticmethod
     def _cube_slice_expression(cube, slice_idx):
         """return `np.s_` object with correct slicing for the cube type."""
@@ -1387,11 +1502,6 @@ class _CatXCatMatrix(BaseCubeResultMatrix):
         """
         return self.column_proportions / self._baseline * 100
 
-    @lazyproperty
-    def columns_base(self):
-        """1D ndarray of np.float64 unweighted-N for each matrix column."""
-        return np.sum(self.unweighted_counts, axis=0)
-
     @lazyproperty
     def columns_margin(self):
         """1D ndarray of np.float64 weighted N for each matrix column."""
@@ -1470,36 +1580,6 @@ class _CatXCatMatrix(BaseCubeResultMatrix):
         """
         return self._weighted_counts
 
-    @lazyproperty
-    def zscores(self):
-        """2D ndarray of np.float64 std-res value for each cell of matrix.
-
-        A z-score is also known as a *standard score* and is the number of standard
-        deviations above (positive) or below (negative) the population mean a cell's
-        value is.
-        """
-        counts = self._weighted_counts
-
-        # --- If the matrix is "defective", in the sense that it doesn't have at least
-        # --- two rows and two columns that are "full" of data, don't calculate zscores.
-        if not np.all(counts.shape) or np.linalg.matrix_rank(counts) < 2:
-            return np.full(counts.shape, np.nan)
-
-        residuals = counts - expected_freq(counts)
-
-        # --- variance of the residuals ---
-        rows_margin = self.rows_margin
-        columns_margin = self.columns_margin
-        table_margin = self.table_margin
-        variance_of_residuals = (
-            np.outer(rows_margin, columns_margin)
-            * np.outer(table_margin - rows_margin, table_margin - columns_margin)
-            / table_margin ** 3
-        )
-
-        with np.errstate(divide="ignore", invalid="ignore"):
-            return residuals / np.sqrt(variance_of_residuals)
-
     @lazyproperty
     def _baseline(self):
         """2D np.float64 ndarray of baseline value for each row in matrix.
@@ -1642,21 +1722,6 @@ class _CatXMrMatrix(_CatXCatMatrix):
         """
         return self._weighted_counts[:, :, 0]
 
-    @lazyproperty
-    def zscores(self):
-        """2D ndarray of np.float64 std-res value for each cell of matrix.
-
-        A z-score is also known as a *standard score* and is the number of standard
-        deviations above (positive) or below (negative) the population mean each cell's
-        value is.
-        """
-        return self._array_type_std_res(
-            self._weighted_counts[:, :, 0],
-            self.table_margin,
-            np.sum(self._weighted_counts, axis=2),
-            np.sum(self._weighted_counts[:, :, 0], axis=0),
-        )
-
     @lazyproperty
     def _baseline(self):
         """2D np.float64 (or NaN) ndarray of baseline value for each matrix cell.
@@ -1711,17 +1776,6 @@ class _MrXCatMatrix(BaseCubeResultMatrix):
           [428 491 290 429]]]
     """
 
-    @lazyproperty
-    def columns_base(self):
-        """2D np.float64 ndarray of unweighted-N for this matrix.
-
-        An MR_X matrix has a distinct column-base for each cell. This is because not all
-        responses (subvars) are necessarily presented to each respondent. The
-        unweighted-count for each MR_X cell is the sum of its selected and unselected
-        unweighted counts.
-        """
-        return np.sum(self._unweighted_counts, axis=1)
-
     @lazyproperty
     def columns_margin(self):
         """2D np.float64 ndarray of weighted-N for each cell of this matrix.
@@ -1814,16 +1868,6 @@ class _MrXCatMatrix(BaseCubeResultMatrix):
         """
         return self._weighted_counts[:, 0, :]
 
-    @lazyproperty
-    def zscores(self):
-        """2D np.float64 ndarray of z-score for each matrix cell."""
-        return self._array_type_std_res(
-            self._weighted_counts[:, 0, :],
-            self.table_margin[:, None],
-            np.sum(self._weighted_counts[:, 0, :], axis=1)[:, None],
-            np.sum(self._weighted_counts, axis=1),
-        )
-
     @lazyproperty
     def _baseline(self):
         """2D np.float64 ndarray of baseline value for each row in matrix.
@@ -1914,17 +1958,6 @@ class _MrXMrMatrix(_CatXCatMatrix):
 
     """
 
-    @lazyproperty
-    def columns_base(self):
-        """2D np.float64 ndarray of unweighted-N for this matrix.
-
-        An MR_X_MR matrix has a distinct column-base for each cell. This is because not
-        all responses (subvars) are necessarily presented to each respondent. The
-        unweighted-count for each MR_X cell is the sum of its selected and unselected
-        unweighted counts.
-        """
-        return np.sum(self._unweighted_counts[:, :, :, 0], axis=1)
-
     @lazyproperty
     def columns_margin(self):
         """2D np.float64 ndarray of weighted-N for each cell of matrix.
@@ -2020,21 +2053,6 @@ class _MrXMrMatrix(_CatXCatMatrix):
         """
         return self._weighted_counts[:, 0, :, 0]
 
-    @lazyproperty
-    def zscores(self):
-        """2D ndarray of np.float64 std-res value for each cell of matrix.
-
-        A z-score is also known as a *standard score* and is the number of standard
-        deviations above (positive) or below (negative) the population mean each cell's
-        value is.
-        """
-        return self._array_type_std_res(
-            self._weighted_counts[:, 0, :, 0],
-            self.table_margin,
-            np.sum(self._weighted_counts, axis=3)[:, 0, :],
-            np.sum(self._weighted_counts, axis=1)[:, :, 0],
-        )
-
     @lazyproperty
     def _baseline(self):
         """2D np.float64 ndarray of baseline value for each matrix cell.
@@ -2067,30 +2085,3 @@ class _MrXMrMatrix(_CatXCatMatrix):
         """2D ndarray of np.float64 table proportion variance for each matrix cell."""
         p = self._weighted_counts[:, 0, :, 0] / self.table_margin
         return p * (1 - p)
-
-
-class _NumArrayXCatMatrix(_CatXCatMatrix):
-    """NUM_ARR_X_CAT slice with means measure instead of counts."""
-
-    @lazyproperty
-    def columns_base(self):
-        """2D np.float64 ndarray of unweighted-N for this matrix.
-
-        In this case the columns base correspond to the unweighted counts that for the
-        numeric arrays cases corresponds to the valid counts measure result.
-        """
-        return self._unweighted_counts
-
-
-class _NumArrayXMrMatrix(_CatXMrMatrix):
-    """NUM_ARR_X_MR slice with means measure instead of counts."""
-
-    @lazyproperty
-    def columns_base(self):
-        """2D np.float64 ndarray of unweighted-N for this matrix.
-
-        A NUM_ARR_X_MR matrix has a distinct column-base for each cell. In this case
-        the column base is the unweighted counts sliced for all the subvar on the NUM
-        ARRAY dimension and all the subvars on the MR (selected) one.
-        """
-        return self._unweighted_counts[:, :, 0]
