@@ -5,12 +5,7 @@
 import pytest
 import numpy as np
 
-from cr.cube.cube import (
-    Cube,
-    CubeSet,
-    _Measures,
-    _ValidCountsMeasure,
-)
+from cr.cube.cube import Cube, CubeSet, _Measures, _UnweightedValidCountsMeasure
 from cr.cube.cubepart import _Slice, _Strand, _Nub
 from cr.cube.enums import DIMENSION_TYPE as DT
 
@@ -698,14 +693,79 @@ class DescribeMeasures(object):
 
         np.testing.assert_equal(population_fraction, expected_value)
 
+    @pytest.mark.parametrize(
+        "cube_dict, expected_value",
+        (
+            (
+                {
+                    "result": {
+                        "filtered": {"weighted_n": 10},
+                        "unfiltered": {"weighted_n": 9},
+                    }
+                },
+                1.1111111111111112,
+            ),
+            ({"result": {}}, 1),
+            ({"result": {"filter_stats": {}}}, 1),
+            ({"result": {"filter_stats": {"filtered_complete": {}}}}, 1),
+            ({"result": {"filter_stats": {"filtered_complete": {"weighted": {}}}}}, 1),
+            (
+                {
+                    "result": {
+                        "filter_stats": {
+                            "filtered_complete": {
+                                "weighted": {"selected": 3, "other": 2}
+                            }
+                        }
+                    }
+                },
+                0.6,
+            ),
+            (
+                {
+                    "result": {
+                        "filter_stats": {
+                            "is_cat_date": False,
+                            "filtered_complete": {
+                                "weighted": {"selected": 3, "other": 2}
+                            },
+                        }
+                    }
+                },
+                0.6,
+            ),
+            (
+                {
+                    "result": {
+                        "filter_stats": {
+                            "is_cat_date": True,
+                            "filtered_complete": {
+                                "weighted": {"selected": 3, "other": 2}
+                            },
+                        }
+                    }
+                },
+                1,
+            ),
+        ),
+    )
+    def and_it_sets_population_fraction_to_one_when_filter_is_a_single_cat_date(
+        self, cube_dict, expected_value
+    ):
+        measures = _Measures(cube_dict, None)
 
-class Describe_ValidCountsMeasure(object):
+        population_fraction = measures.population_fraction
+
+        assert population_fraction == expected_value
+
+
+class Describe_UweightedValidCountsMeasure(object):
     @pytest.mark.parametrize(
         "valid_counts, expected_value",
         (({"valid_count_unweighted": {"data": [3, 2, 1]}}, [3, 2, 1]), ({}, None)),
     )
     def it_knows_its_flat_values(self, valid_counts, expected_value):
         cube_dict = {"result": {"measures": valid_counts}}
-        valid_counts = _ValidCountsMeasure(cube_dict, None)
+        valid_counts = _UnweightedValidCountsMeasure(cube_dict, None)
 
         np.testing.assert_equal(valid_counts._flat_values, expected_value)
